@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_KEYBOARD_H
 #define WAYLAND_KEYBOARD_H
 
@@ -30,7 +16,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class Surface;
 
 /**
@@ -48,7 +33,7 @@ class KWAYLANDCLIENT_EXPORT Keyboard : public QObject
 public:
     enum class KeyState {
         Released,
-        Pressed
+        Pressed,
     };
     explicit Keyboard(QObject *parent = nullptr);
     virtual ~Keyboard();
@@ -73,12 +58,12 @@ public:
      **/
     void release();
     /**
-     * Destroys the data hold by this Keyboard.
+     * Destroys the data held by this Keyboard.
      * This method is supposed to be used when the connection to the Wayland
-     * server goes away. If the connection is not valid any more, it's not
-     * possible to call release any more as that calls into the Wayland
+     * server goes away. If the connection is not valid anymore, it's not
+     * possible to call release anymore as that calls into the Wayland
      * connection and the call would fail. This method cleans up the data, so
-     * that the instance can be deleted or setup to a new wl_keyboard interface
+     * that the instance can be deleted or set up to a new wl_keyboard interface
      * once there is a new connection available.
      *
      * This method is automatically invoked when the Seat which created this
@@ -97,8 +82,33 @@ public:
      **/
     Surface *enteredSurface();
 
-    operator wl_keyboard*();
-    operator wl_keyboard*() const;
+    /**
+     * @returns Whether key repeat is enabled on this keyboard
+     * @see keyRepeatRate
+     * @see keyRepeatDelay
+     * @see keyRepeatChanged
+     * @since 5.5
+     **/
+    bool isKeyRepeatEnabled() const;
+    /**
+     * @returns the key repeat rate in characters per second.
+     * @see isKeyRepeatEnabled
+     * @see keyRepeatDelay
+     * @see keyRepeatChanged
+     * @since 5.5
+     **/
+    qint32 keyRepeatRate() const;
+    /**
+     * @returns the delay in millisecond for key repeat after a press.
+     * @see isKeyRepeatEnabled
+     * @see keyRepeatRate
+     * @see keyRepeatChanged
+     * @since 5.5
+     **/
+    qint32 keyRepeatDelay() const;
+
+    operator wl_keyboard *();
+    operator wl_keyboard *() const;
 
 Q_SIGNALS:
     /**
@@ -138,6 +148,14 @@ Q_SIGNALS:
      * and it should update its local state.
      **/
     void modifiersChanged(quint32 depressed, quint32 latched, quint32 locked, quint32 group);
+    /**
+     * Emitted whenever information on key repeat changed.
+     * @see isKeyRepeatEnabled
+     * @see keyRepeatRate
+     * @see keyRepeatDelay
+     * @since 5.5
+     **/
+    void keyRepeatChanged();
 
 private:
     class Private;
